@@ -1,24 +1,47 @@
-from django.core.exceptions import FieldDoesNotExist
+import logging
+from collections import namedtuple
+
 from django.contrib import admin
+from django.core.exceptions import FieldDoesNotExist
 from django.http import HttpResponse
 from django.utils.encoding import force_text
+from django.utils.translation import ugettext_lazy as _
 from import_export import fields, resources, widgets
+from tablib import Dataset
 
+ExportType = namedtuple("ExportType", ("mimetype", "label"))
+
+# Map from supported export types to their content type used for file to download.
+# {extension: (mimetype, label), ...}
 EXPORT_TYPES_TO_CONTENT_TYPES = {
-    'csv': 'text/csv',
-    'tsv': 'text/tab-separated-values',
-    'xls': 'application/vnd.ms-excel',
-    'xlsx': 'application/vnd.ms-excel',
-    'ods': 'application/vnd.oasis.opendocument.spreadsheet',
-    'json': 'application/json',
-    # These formats are no longer supported. Use other project (django-import-export).
-    # 'yaml': 'text/plain',
-    # 'html': 'text/html',
+    'csv': ExportType('text/csv', _('Export selected as CSV')),
+    'tsv': ExportType('text/tab-separated-values', _('Export selected as TSV (Tab-Separated Values)')),
+    'xls': ExportType('application/vnd.ms-excel', _('Export selected as XLS')),
+    'xlsx': ExportType('application/vnd.ms-excel', _('Export selected as XLSX')),
+    'ods': ExportType('application/vnd.oasis.opendocument.spreadsheet', _('Export selected as ODS')),
+    'json': ExportType('application/json', _('Export selected as JSON')),
+    'yaml': ExportType('text/plain', _('Export selected as YAML')),
+    'html': ExportType('text/html', _('Export selected as HTML')),
+    'latex': ExportType('application/x-latex', _('Export selected as LATEX (LaTeX Source Document)')),
+    'rst': ExportType('text/x-rst', _('Export selected as RST (reStructuredText)')),
 }
-"""
-Map from supported export types to their content type
-used for file to download.
-"""
+
+logger = logging.getLogger(__name__)
+
+
+def get_supported_export_types():
+    """
+    Get only the export types supported by this operating system.
+    """
+    dataset = Dataset()
+    available_types = {}
+    for ext, item in EXPORT_TYPES_TO_CONTENT_TYPES.items():
+        try:
+            getattr(dataset, ext)
+            available_types[ext] = item
+        except (ImportError, AttributeError) as error:
+            logger.info(error)
+    return available_types
 
 
 def register_export_action(export_type, label):
@@ -46,10 +69,11 @@ def export_file(export_type, modeladmin, queryset):
     Same as :any:`cms_qe.export.export_data` but wraps it into
     :any:`django.http.HttpResponse` as file to download.
     """
-    if export_type not in EXPORT_TYPES_TO_CONTENT_TYPES:
+    export_types = get_supported_export_types()
+    if export_type not in export_types:
         raise Exception('Type {} is not supported'.format(export_type))
 
-    content_type = EXPORT_TYPES_TO_CONTENT_TYPES[export_type]
+    content_type = export_types[export_type].mimetype
     data = export_data(export_type, modeladmin, queryset)
     response = HttpResponse(data, content_type=content_type)
     response['Content-Disposition'] = 'attachment; filename="export.{}"'.format(export_type)
@@ -58,9 +82,12 @@ def export_file(export_type, modeladmin, queryset):
 
 def export_data(export_type, modeladmin, queryset):
     """
-    Export data as ``export_type``. Supported are only those in
-    constant ``EXPORT_TYPES_TO_CONTENT_TYPES``.
+    Export data as ``export_type``. Supported are only those from
+    function ``get_supported_export_types``.
     """
+    if hasattr(modeladmin, "export_data"):
+        return modeladmin.export_data(export_type, queryset)
+
     model_fields = queryset.model._meta.get_fields()
 
     class ObjectResourceMeta(resources.ModelDeclarativeMetaclass):
@@ -86,7 +113,7 @@ def export_data(export_type, modeladmin, queryset):
             # are visible on the web to the user, it's good to include them
             # in the export as well.
             for field_name in modeladmin.list_display:
-                if field_name in attrs:
+                if field_name in attrs or field_name[:2] == '__':
                     continue
                 attrs[field_name] = AdminField(
                     attribute=field_name,
@@ -145,11 +172,12 @@ class AdminField(fields.Field):
     """
 
     def __init__(self, *args, **kwds):
-        self.modeladmin = kwds.pop('modeladmin')
+        modeladmin = kwds.pop('modeladmin')
+        self.get_modeladmin = lambda: modeladmin
         super().__init__(*args, **kwds)
 
     def get_value(self, obj):
-        admin_property = getattr(self.modeladmin, self.attribute, None)
+        admin_property = getattr(self.get_modeladmin(), self.attribute, None)
         if admin_property:
             return admin_property(obj)
         return super().get_value(obj)
