@@ -1,10 +1,9 @@
 from django import forms
+from django.contrib.auth import get_user_model
 from django.contrib.auth.forms import PasswordResetForm, UserCreationForm
 from django.core.exceptions import ValidationError
 from django.utils.translation import ugettext_lazy as _
 
-from .models import User
-
 
 class RegisterForm(UserCreationForm):
     """
@@ -15,8 +14,8 @@ class RegisterForm(UserCreationForm):
     email = forms.EmailField(required=True)
 
     class Meta:
-        model = User
-        fields = ('username', 'email', 'password1', 'password2')
+        model = get_user_model()
+        fields = ('username', 'email', 'first_name', 'last_name', 'password1', 'password2')
 
 
 class PasswordResetFormWithEmailExistenceCheck(PasswordResetForm):
@@ -28,6 +27,6 @@ class PasswordResetFormWithEmailExistenceCheck(PasswordResetForm):
 
     def clean_email(self):
         email = self.cleaned_data['email']
-        if not User.objects.filter(email=email).exists():
+        if not get_user_model().objects.filter(email=email).exists():  # pylint: disable=no-member
             raise ValidationError(_("Email does not exists"))
         return email
