@@ -21,7 +21,7 @@ def test_uidb64_to_pk(pk, uid):
 
 @pytest.mark.parametrize(*UIDB64_TEST_DATA)
 def test_pk_to_uidb64(pk, uid):
-    assert pk_to_uidb64(pk) == uid.encode()
+    assert pk_to_uidb64(pk) == uid
 
 
 @use_data(user_data={'id': 1})
