@@ -13,4 +13,4 @@ class BreadcrumbPlugin(CMSPluginBase):
 
     name = _('Breadcrumb')
     render_template = 'cms_qe/breadcrumb/breadcrumb_tag.html'
-    cache = True
+    cache = False
