@@ -3,7 +3,7 @@ from webdriverwrapper.decorators import expected_error_page
 from ..pages.cms import CreatePagePage
 
 
-@expected_error_page('Generic error')
+@expected_error_page(None)
 def test_page_not_found(driver):
     driver.go_to('/404')
 
